---
title: Key Bindings Reference
---



# Global

| Key | Action |
| --- | --- |
| ctrl-O | Open file |
| ctrl-shift-O | Open project |
| ctrl-R | Reload current file |
| ctrl-S | Save current file |
| ctrl-shift-S | Save current file with new name |
| ctrl-Q | Exit |


# Hex Editor

| Key | Action |
| --- | --- |
| ctrl-A | Select all of current buffer |
| ctrl-C | Copy selection as undelimited hex string |
| ctrl-shift-C | Copy selection as formatted hex dump |
| ctrl-F5 | Re-apply format info |
| ctrl-plus | Zoom in |
| ctrl-minus | Zoom out |
| ctrl-0 | Reset zoom level |
| X | Delete selected annotation |
| R, G, Y, L, M, T | Annotate with background color (Red, Green, Yellow, bLue, Magenta, Turqoise) |



# Code Editor

| Key | Action |
| --- | --- |
| ctrl-J | Add next occurrence to selection |
| ctrl-shift J | Add all occurrences to selection |




# Grammar Definition Code

| Key | Action |
| --- | --- |
| ctrl-ENTER | Apply changes |


